package com.iconplus.smartproc.service.drp;

import com.iconplus.smartproc.exception.BusinessException;
import com.iconplus.smartproc.helper.service.BaseService;
import com.iconplus.smartproc.model.request.DrpRequest;
import com.iconplus.smartproc.model.response.DrpResponse;
import com.iconplus.smartproc.repository.DrpRepository;
import com.iconplus.smartproc.util.Constants;
import org.springframework.stereotype.Service;

@Service
public class GetDrpService implements BaseService<DrpRequest, DrpResponse> {

    private final DrpRepository drpRepository;

    public GetDrpService(DrpRepository drpRepository) {
        this.drpRepository = drpRepository;
    }

    @Override
    public DrpResponse execute(DrpRequest input) {
        var drp = drpRepository.findByIdAndIsDeleteFalse(input.getId())
                .orElseThrow(() -> new BusinessException(Constants.ERR_CODE_10001,
                        Constants.ERR_TTL_10001,
                        String.format(Constants.ERR_MSG_10001, "DRP", input.getId())));

        return DrpResponse.builder()
                .id(drp.getId())
                .tahun(drp.getTahun())
                .isApprove(drp.getIsApprove())
                .approveDate(drp.getApproveDate())
                .isActive(drp.getIsActive())
                .isDelete(drp.getIsDelete())
                .build();
    }
}
